%define anolis_release 38

Summary: Anolis OS specific rpm configuration files
Name: system-rpm-config
Epoch: 1
Version: 23
Release: %{anolis_release}%{?dist}
# check-desktop-files licensed under MIT, other script under MulanPSLv2
License: MulanPSLv2 and MIT
URL: https://gitee.com/src-anolis-os/system-rpm-config

# Core rpm settings
Source0: macros
Source1: rpmrc

Source10: MulanPSL 

# gcc specs files for hardened builds
Source50: anolis-hardened-cc1
Source51: anolis-hardened-ld
Source52: anolis-hardened-clang.cfg

# gcc specs files for annobin builds
Source60: anolis-annobin-cc1

# The macros defined by these files are for things that need to be defined
# at srpm creation time when it is not feasible to require the base packages
# that would otherwise be providing the macros. other language/arch specific
# macros should not be defined here but instead in the base packages that can
# be pulled in at rpm build time, this is specific for srpm creation.
Source100: macros.anolis-misc-srpm
Source101: macros.nodejs-srpm
Source102: macros.java-srpm
Source103: macros.fpc-srpm
Source104: macros.ghc-srpm
Source105: macros.gnat-srpm

# Other misc macros
Source150: macros.build-constraints
Source151: macros.dwz
Source152: macros.anolis-misc
Source153: macros.ldconfig
# meson depend on this
Source154: macros.vpath
Source155: macros.forge
Source156: macros.shell-completions

# Build policy scripts
# this comes from https://github.com/rpm-software-management/rpm/pull/344
Source201: brp-mangle-shebangs
# for converting llvm LTO bitcode objects into ELF
Source202: brp-llvm-compile-lto-elf

# Dependency generator scripts (deprecated)
Source300: find-provides
Source301: find-requires

# Misc helper scripts
Source400: dist.sh
Source401: gpgverify
Source402: remove-info-dir
Source403: fix-dlsearch-path-in-libtool
Source404: generate-compatibility-deps
Source405: relink_symlinks
Source406: check-desktop-files
Source407: clean_perl
Source408: check_elf_files
Source409: fix-libtool-ltmain-from-overlinking
Source410: fix-libtool-from-moving-options-after-libs
Source411: force-as-needed-for-shared-lib-in-libtool

# 2022-05-25 Snapshots from http://git.savannah.gnu.org/gitweb/?p=config.git
Source500: config.guess
Source501: config.sub

# Dependency generators & their rules
Source602: libsymlink.attr

# BRPs
Source700: brp-ldconfig
Source701: brp-strip-lto

# Convenience lua functions
Source800: common.lua
Source801: forge.lua

Source900: compatibility-deps.sh
Source901: abi.attr
Source902: api.attr

BuildArch: noarch
BuildRequires: perl-generators
Requires: coreutils

Requires: rpm >= 4.11.0
Requires: dwz >= 0.4
Requires: zip
Requires: (annobin-plugin-gcc if gcc)

# for brp-mangle-shebangs
Requires: %{_bindir}/find
Requires: %{_bindir}/file
Requires: %{_bindir}/grep
Requires: %{_bindir}/sed
Requires: %{_bindir}/xargs

# for installed_version_of macro
Requires: %{_bindir}/awk

# for brp_check_desktop_files
Requires: desktop-file-utils

# for brp-llvm-compile-lto-elf
Requires: (llvm if clang)

Provides: system-rpm-config = %{version}-%{release}

Requires: go-srpm-macros
Requires: python3-rpm-macros
Requires: efi-srpm-macros
Requires: perl-srpm-macros
Requires: rust-srpm-macros
Requires: ocaml-srpm-macros
Requires: abi-dumper

%global rrcdir /usr/lib/rpm/anolis

%description
Anolis OS specific rpm configuration files.

%prep
# Not strictly necessary but allows working on file names instead
# of source numbers in install section
%setup -c -T
cp -p %{sources} .

%install
mkdir -p %{buildroot}%{rrcdir}
install -p -m 644 -t %{buildroot}%{rrcdir} macros rpmrc
install -p -m 444 -t %{buildroot}%{rrcdir} anolis-hardened-*
install -p -m 444 -t %{buildroot}%{rrcdir} anolis-annobin-*
install -p -m 755 -t %{buildroot}%{rrcdir} config.*
install -p -m 755 -t %{buildroot}%{rrcdir} dist.sh
install -p -m 755 -t %{buildroot}%{rrcdir} gpgverify
install -p -m 755 -t %{buildroot}%{rrcdir} brp-*
install -p -m 755 -t %{buildroot}%{rrcdir} remove-info-dir
install -p -m 755 -t %{buildroot}%{rrcdir} fix-dlsearch-path-in-libtool
install -p -m 755 -t %{buildroot}%{rrcdir} fix-libtool-ltmain-from-overlinking
install -p -m 755 -t %{buildroot}%{rrcdir} fix-libtool-from-moving-options-after-libs
install -p -m 755 -t %{buildroot}%{rrcdir} force-as-needed-for-shared-lib-in-libtool
install -p -m 755 -t %{buildroot}%{rrcdir} generate-compatibility-deps
install -p -m 755 -t %{buildroot}%{rrcdir} relink_symlinks
install -p -m 755 -t %{buildroot}%{rrcdir} check-desktop-files
install -p -m 755 -t %{buildroot}%{rrcdir} clean_perl
install -p -m 755 -t %{buildroot}%{rrcdir} check_elf_files

install -p -m 755 -t %{buildroot}%{rrcdir} find-*
mkdir -p %{buildroot}%{rrcdir}/find-provides.d

install -p -m 755 -t %{buildroot}%{rrcdir} brp-*

mkdir -p %{buildroot}%{_rpmconfigdir}
install -p -m 755 -t %{buildroot}%{_rpmconfigdir} compatibility-deps.sh

mkdir -p %{buildroot}%{_rpmconfigdir}/macros.d
install -p -m 644 -t %{buildroot}%{_rpmconfigdir}/macros.d macros.*
mkdir -p %{buildroot}%{_fileattrsdir}
install -p -m 644 -t %{buildroot}%{_fileattrsdir} *.attr

mkdir -p %{buildroot}%{_rpmluadir}/anolis/{rpm,srpm}
install -p -m 644 -t %{buildroot}%{_rpmluadir}/anolis common.lua
install -p -m 644 -t %{buildroot}%{_rpmluadir}/anolis/srpm forge.lua

%files
%dir %{rrcdir}
%{rrcdir}/macros
%{rrcdir}/rpmrc
%{rrcdir}/brp-*
%{rrcdir}/dist.sh
%{rrcdir}/gpgverify
%{rrcdir}/anolis-hardened-*
%{rrcdir}/anolis-annobin-*
%{rrcdir}/config.*
%{rrcdir}/check-desktop-files
%{rrcdir}/check_elf_files
%{rrcdir}/clean_perl
%{rrcdir}/find-provides
%{rrcdir}/find-requires
%{rrcdir}/remove-info-dir
%{rrcdir}/relink_symlinks
%{rrcdir}/fix-dlsearch-path-in-libtool
%{rrcdir}/fix-libtool-from-moving-options-after-libs
%{rrcdir}/fix-libtool-ltmain-from-overlinking
%{rrcdir}/force-as-needed-for-shared-lib-in-libtool
%{rrcdir}/generate-compatibility-deps
%{_fileattrsdir}/*.attr
%{_rpmconfigdir}/compatibility-deps.sh
%{_rpmconfigdir}/macros.d/macros.*-srpm
%{_rpmconfigdir}/macros.d/macros.build-constraints
%{_rpmconfigdir}/macros.d/macros.dwz
%{_rpmconfigdir}/macros.d/macros.anolis-misc
%{_rpmconfigdir}/macros.d/macros.ldconfig
%{_rpmconfigdir}/macros.d/macros.shell-completions
%{_rpmconfigdir}/macros.d/macros.vpath
%{_rpmconfigdir}/macros.d/macros.forge
%dir %{_rpmluadir}/anolis
%dir %{_rpmluadir}/anolis/srpm
%dir %{_rpmluadir}/anolis/rpm
%{_rpmluadir}/anolis/*.lua
%{_rpmluadir}/anolis/srpm/*.lua
%license MulanPSL

%changelog
* Tue Apr 22 2025 Yihao Yan <yan.yihao@zte.com.cn> - 1:23-38
- add riscv64 for java and nodejs macros
- add optflags for riscv64

* Wed Jul 24 2024 Wenlong Zhang <zhangwenlong@loongson.cn> - 1:23-37
- add timeout when create option.list

* Wed Jul 17 2024 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1:23-36
- brp-mangle-shebangs: remove python2 related

* Fri Mar 15 2024 Chang Gao <gc-taifu@linux.alibaba.com> - 1:23-35
- Remove -fno-openmp-implicit-rpath clang ldflags

* Sun Oct  8 2023 Wenlong Zhang<zhangwenlong@loongson.cn> - 1:23-34
- add loongarch64 for nodejs and java macros
- add optflags for loongarch64

* Sat Apr 15 2023 Funda Wang <fundawang@yeah.net> - 1:23-33
- Drop unused flags for fortran

* Mon Apr 10 2023 Funda Wang <fundawang@yeah.net> - 1:23-32
- Fix clean_perl directory depth

* Mon Mar 27 2023 happy_orange <songnannan@linux.alibaba.com> - 1:23-31
- add some src macros

* Tue Mar 21 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1:23-30
- add requires of ocaml-srpm-macros

* Thu Mar 09 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1:23-29
- remove unnecessary provides

* Wed Mar 08 2023 Funda Wang <fundawang@yeah.net> - 1:23-28
- Fix output of installed_version_of macro when package is not installed
- Cleanup macros

* Fri Feb 24 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1:23-27
- remove __brp_relink_symlinks temporarily

* Fri Feb 17 2023 Funda Wang <fundawang@yeah.net> - 1:23-26
- Add helper macro for packagers to detect installed version of package
- Add helper script forcing as-needed for libtool linking bugs

* Sat Feb 11 2023 Funda Wang <fundawang@yeah.net> - 1:23-25
- Add helper scripts from mageia to fix overlinking of shared libs

* Mon Feb 6 2023 Funda Wang <fundawang@yeah.net> - 1:23-24
- Fix output of undefined symbols detections

* Sat Feb 4 2023 Funda Wang <fundawang@yeah.net> - 1:23-23
- Add helper scripts from Mageia for clean perl files and display
  warnings against shared libs
- Add EVR macro to simplify epoch:version-release usage

* Mon Jan 30 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1:23-22
- requires abi-dumper

* Mon Jan 30 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1:23-21
- recover to requires abi-dumper

* Mon Jan 30 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1:23-20
- Temporarily remove requires of abi-dumper (for perl update)

* Wed Jan 25 2023 Funda Wang <fundawang@yeah.net> - 1:23-19
- Add macros.build-constraints from upstream for huge packages

* Sun Jan 15 2023 Funda Wang <fundawang@yeah.net> - 1:23-18
- Add man pages compression extension macro

* Thu Dec 22 2022 Funda Wang <fundawang@yeah.net> - 1:23-17
- Bump epoch for upgrading from anolis 8

* Thu Dec 8 2022 Funda Wang <fundawang@yeah.net> - 23-16
- Add check script from Mageia for .desktop files

* Sun Nov 20 2022 Funda Wang <fundawang@yeah.net> - 23-15
- Add symlink relink helper from Mageia to reduce absolute symlink
- move la_file removal step ahead, so that they do not trigger shebangs

* Wed Nov 9 2022 Funda Wang <fundawang@yeah.net> - 23-14
- Compress man-pages and info-pages as zstd to save disk space for users.

* Thu Oct 27 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 23-13
- generate-compatibility-deps: process BUILDROOT in api files

* Tue Oct 25 2022 Chunmei Xu <xuchunmei@linux.aliabba.com> - 23-12
- generate-compatibility-deps: fix empty api files

* Fri Oct 21 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 23-11
- generate-compatibility-deps: remove unexpected files

* Fri Oct 14 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 23-10
- add generate-compatibility-deps to generate abi/api files

* Tue Oct 11 2022 happy_orange <songnannan@linux.alibaba.com> - 23-9
- change the filter matching rules for abi and api fileattr.

* Tue Oct 11 2022 Funda Wang <fundawang@yeah.net> - 23-8
- add fix-dlsearch-path-in-libtool from mageia for automatically fix sys_lib_dlsearch_path_spec
  in configure script shipped in packages

* Sun Oct 09 2022 Funda Wang <fundawang@yeah.net> - 23-7
- add remove-info-dir script from mandriva/mageia for automatically removal of unwanted /usr/share/info/dir

* Fri Sep 30 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 23-6
- add abi and api fileattr to provides abi/api

* Thu Aug 25 2022 happy_orange <songnannan@linux.alibaba.com> - 23-5
- add some nodejs-srpm and java-srpm in macros
- brp-llvm-compile-lto-elf needs to run earlier to fix the error of Unpacking ar archive
- add %%__brp_remove_la_files to %%__os_install_post

* Wed Mar 16 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 23-4
- fix __cflags_arch_x86_64

* Tue Mar 15 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 23-3
- set rust-srpm-macros as requires

* Thu Mar 10 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 23-2
- add macros.forge and some srpm-macros as Requires

* Tue Feb 08 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 23-1
- init package
